@@ -4,7 +4,7 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.45.1")
+(defparameter *autoconf-version* "5.46.0")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
@@ -15,10 +15,10 @@
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
-(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now")
+(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto")
 
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/build/maxima/src/maxima-5.45.1")
+(defparameter *maxima-source-root* "/build/maxima/src/maxima-5.46.0")
 (defparameter *maxima-default-layout-autotools* "true")
